import * as React from 'react';
import { IgRect } from "igniteui-react-core";
import { Popup } from './Popup';
import { IgrOnPopupEventArgs } from './igr-on-popup-event-args';
import { IgrOnClosedEventArgs } from './igr-on-closed-event-args';
import { PopupDirection } from "./PopupDirection";
import { PopupAlignment } from "./PopupAlignment";
export declare class IgrPopup extends React.Component<IIgrPopupProps> {
    private _height;
    private _width;
    private _initialized;
    private _elRef;
    private _contentAreaInnerRef;
    private _contentAreaOuterRef;
    private _reactRenderer;
    private _implementation;
    private _portalManager;
    height: string;
    width: string;
    private _getMainRef;
    private verifyReferences;
    render(): React.DetailedReactHTMLElement<{
        ref: (ref: any) => void;
        children: any[];
    }, any>;
    private requestRender;
    constructor(props: IIgrPopupProps);
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    protected initializeProperties(): void;
    updateStyle(): void;
    componentWillUnmount(): void;
    componentDidMount(): void;
    initializeContent(): void;
    protected createImplementation(): Popup;
    readonly i: Popup;
    /**
 * Gets or sets the duration of the Popup and Closeup animations in milliseconds.
*/
    animationDuration: number;
    /**
     * Gets or sets whether the popup and closeup animations are animated.
    */
    animationEnabled: boolean;
    /**
     * Gets or sets the elevation to use for the button regardless of type.
    */
    elevation: number;
    /**
     * Gets or sets the elevation of the border shadow
    */
    actualElevation: number;
    /**
     * Gets / sets the isShown state of the panel.
    */
    readonly isShown: boolean;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualUmbraShadowColor: string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualPenumbraShadowColor: string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualAmbientShadowColor: string;
    /**
     * Gets or sets the background color of the popup.
    */
    background: string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected readonly hasUserValues: Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Closes the popup.

*/
    close(): void;
    showRelativeToExclusionRect(exclusionRect: IgRect, popupDirection: PopupDirection, popupAlignment: PopupAlignment): void;
    /**
     * Exports visual information about the current state of the grid.
    
    */
    exportVisualModel(): any;
    /**
     * Returns a serialized copy of the exported visual model
    
    */
    exportSerializedVisualModel(): string;
    private _onClosed;
    private _onClosed_wrapped;
    onClosed: (s: IgrPopup, e: IgrOnClosedEventArgs) => void;
    private _onPopup;
    private _onPopup_wrapped;
    /**
     * Fires when the popup is shown
    */
    onPopup: (s: IgrPopup, e: IgrOnPopupEventArgs) => void;
}
export interface IIgrPopupProps {
    width?: string;
    height?: string;
    /**
 * Gets or sets the duration of the Popup and Closeup animations in milliseconds.
*/
    animationDuration?: number | string;
    /**
     * Gets or sets whether the popup and closeup animations are animated.
    */
    animationEnabled?: boolean | string;
    /**
     * Gets or sets the elevation to use for the button regardless of type.
    */
    elevation?: number | string;
    /**
     * Gets or sets the elevation of the border shadow
    */
    actualElevation?: number | string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualUmbraShadowColor?: string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualPenumbraShadowColor?: string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualAmbientShadowColor?: string;
    /**
     * Gets or sets the background color of the popup.
    */
    background?: string;
    onClosed?: (s: IgrPopup, e: IgrOnClosedEventArgs) => void;
    /**
     * Fires when the popup is shown
    */
    onPopup?: (s: IgrPopup, e: IgrOnPopupEventArgs) => void;
}
